/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: PRECOS_TO_REGIAO                                                     */
/*                                                                            */
/* Descrio:                                                                 */
/*   Carrega os precos para uma regio informada.                             */
/*   Carrega tambm os dados necessrios para o clculo do preo econmico    */
/* Criao:                                                                   */
/*    31/07/2000 - Adriano de Araujo                                          */
/*                                                                            */
/* Manutenes:                                                               */
/*   /  /   -                                                                 */
/*                                                                            */
/******************************************************************************/
/* ESTA PROCEDURE E CHAMADA NA TELA DE INCLUSAO DE REGIAO(DUPLICA UMA REGIAO) */
/* E NA TELA DE PLANILHA DE COTACAO AO ALTERAR UM PRECO(DUPLICA PARA TODAS REGIOES)*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'PRECOS_TO_REGIAO'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)

   DROP PROCEDURE PRECOS_TO_REGIAO;
GO

CREATE PROCEDURE PRECOS_TO_REGIAO
                         @P_CDFILIAL     VARCHAR(4),
                         @P_CDFILIPROC   VARCHAR(4),
                         @P_NRCOLEPRECO  VARCHAR(10),
                         @P_CDREGIAO     VARCHAR(3),
                         @P_CDFORNECED   VARCHAR(21),
                         @P_TFORN        VARCHAR(1),
                         @P_CDPRODUTO    VARCHAR(10),
                         @P_CDMARCA      VARCHAR(5),
                         @P_IDATUREG     VARCHAR(1),
                         @P_IDATUFORN    VARCHAR(1),
                         @P_NEW_CDREGIAO VARCHAR(3) = NULL
/* P_NEW_CDREGIAO <> NULL >> DUPLICA PARA UMA REGIAO */
/* P_NEW_CDREGIAO = NULL  >> DUPLICA PARA TODAS REGIOES */
AS
   DECLARE @V_CDEMPRESA  VARCHAR(2);
   DECLARE @V_CDINSCMUNI VARCHAR(16);
   DECLARE @V_CDINSCESTA VARCHAR(16);

   DECLARE @V_DTCOLEPREC DATETIME;

   DECLARE @V_REGIAO_CDREGIAO VARCHAR(3);

   DECLARE @V_PRECOS_CDFORNECED    VARCHAR(21);
   DECLARE @V_PRECOS_CDPRODUTO     VARCHAR(10);
   DECLARE @V_PRECOS_CDARVPROD     VARCHAR(20);
   DECLARE @V_PRECOS_CDMARCA       VARCHAR(5);
   DECLARE @V_PRECOS_VRPRECUNIITM  NUMERIC(15, 5);
   DECLARE @V_PRECOS_CDFORMPGTO    VARCHAR(2);
   DECLARE @V_PRECOS_IDTPFOPGTCOL  VARCHAR(1);
   DECLARE @V_PRECOS_NRPARCPGTCOL  NUMERIC(2);
   DECLARE @V_PRECOS_NRDIAPGFXCOL  NUMERIC(2);
   DECLARE @V_PRECOS_IDUTDIAPGCOL  VARCHAR(1);
   DECLARE @V_COUNTAUX             NUMERIC;
   DECLARE @V_NRSEQPRELIST         VARCHAR(10);
   DECLARE @V_IDPRECALT            VARCHAR(1);
BEGIN
   SELECT
      @V_NRSEQPRELIST = MAX(NRSEQPRELIST),
      @V_IDPRECALT    = MAX(IDPRECALT)
   FROM
      ITEMCOLE
   WHERE ITEMCOLE.CDFILIAL    = @P_CDFILIAL
     AND ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO;
   DECLARE C_REGIAO CURSOR FOR
      SELECT DISTINCT
         CDREGIAO
      FROM
         ITEMCOLE
      WHERE
         ITEMCOLE.CDFILIAL    = @P_CDFILIAL    AND
         ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO AND
         ITEMCOLE.CDREGIAO    <> @P_CDREGIAO   AND
         ITEMCOLE.CDREGIAO    = ISNULL(@P_NEW_CDREGIAO, ITEMCOLE.CDREGIAO) AND
         NOT EXISTS(SELECT
                       CDFORNECED,
                       CDREGIAO
                    FROM
                       REFOREG
                    WHERE
                       REFOREG.CDFORNECED = ITEMCOLE.CDFORNECED AND
                       REFOREG.CDREGIAO   = ITEMCOLE.CDREGIAO);
/* CURSOR QUE RETORNA TODAS AS REGIOES DE DESTINO DA DUPLICACAO */
   OPEN C_REGIAO;
   FETCH NEXT FROM C_REGIAO INTO @V_REGIAO_CDREGIAO;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      IF @P_NEW_CDREGIAO IS NOT NULL
      BEGIN
         INSERT INTO PZOPGTITMCOL
         (CDFILIAL, NRCOLEPRECO,  CDFORNECED,   CDPRODUTO,
          CDMARCA,  NRDIASPGTCOL, VRPERCPGTCOL, CDREGIAO)
         SELECT
          PZOPGTITMCOL.CDFILIAL, PZOPGTITMCOL.NRCOLEPRECO, PZOPGTITMCOL.CDFORNECED,
          PZOPGTITMCOL.CDPRODUTO,PZOPGTITMCOL.CDMARCA, PZOPGTITMCOL.NRDIASPGTCOL,
          PZOPGTITMCOL.VRPERCPGTCOL, @P_NEW_CDREGIAO
         FROM
          PZOPGTITMCOL,
          ITEMCOLE
         WHERE
          PZOPGTITMCOL.CDFILIAL    = @P_CDFILIAL    AND
          PZOPGTITMCOL.NRCOLEPRECO = @P_NRCOLEPRECO AND
          PZOPGTITMCOL.CDREGIAO    = @P_CDREGIAO    AND
          (PZOPGTITMCOL.CDFORNECED = @P_CDFORNECED OR @P_TFORN = 'T') AND

          ITEMCOLE.CDREGIAO        = @P_NEW_CDREGIAO      AND
          PZOPGTITMCOL.CDFILIAL    = ITEMCOLE.CDFILIAL    AND
          PZOPGTITMCOL.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO AND
          PZOPGTITMCOL.CDFORNECED  = ITEMCOLE.CDFORNECED  AND
          PZOPGTITMCOL.CDPRODUTO   = ITEMCOLE.CDPRODUTO   AND
          PZOPGTITMCOL.CDMARCA     = ITEMCOLE.CDMARCA     AND
          NOT EXISTS (SELECT 1 FROM PZOPGTITMCOL P
                              WHERE PZOPGTITMCOL.CDFILIAL         = P.CDFILIAL    AND
                                    PZOPGTITMCOL.NRCOLEPRECO      = P.NRCOLEPRECO AND
                                    PZOPGTITMCOL.CDFORNECED       = P.CDFORNECED  AND
                                    PZOPGTITMCOL.CDPRODUTO        = P.CDPRODUTO   AND
                                    PZOPGTITMCOL.CDMARCA          = P.CDMARCA     AND
                                    PZOPGTITMCOL.CDREGIAO         = P.CDREGIAO    AND
                                    PZOPGTITMCOL.NRDIASPGTCOL     = P.NRDIASPGTCOL);
      END
      ELSE BEGIN
         IF @P_CDFORNECED IS NOT NULL BEGIN
            SET @V_COUNTAUX = 0;
            SELECT
               @V_COUNTAUX = COUNT(*)
            FROM
               ITEMCOLE
            WHERE
               CDFILIAL    = @P_CDFILIAL    AND
               NRCOLEPRECO = @P_NRCOLEPRECO AND
               CDFORNECED  = @P_CDFORNECED  AND
               CDPRODUTO   = @P_CDPRODUTO   AND
               CDMARCA     = @P_CDMARCA     AND
               CDREGIAO    = @V_REGIAO_CDREGIAO;
/* SE NA REGIAO DE DESTINO NAO HOUVER O PRODUTO DUPLICADO ENTAO ELE SERA INSERIDO */
            IF @V_COUNTAUX = 0 BEGIN
               INSERT INTO ITEMCOLE(CDFILIAL, NRCOLEPRECO, CDPRODUTO, CDMARCA, CDFORNECED,
                                    CDREGIAO, DTINIVALITM, DTFINVALITM,
                                    VRPRECUNIITM, VRPERDESITM, IDITMCOTPREC,
                                    CDTIPCOB, CDSEGMARCCOL, IDTIPFREITM, NRPZOENTCOL,
                                    IDITMLISPREC, CDFORMPGTO, IDTPFOPGTCOL, NRPARCPGTCOL,
                                    NRDIAPGFXCOL, IDUTDIAPGCOL, QTACMPITMCOL,
                                    DSPZOPGTCONC, IDATUREGIINC, IDATUFORNINC, NRSEQPRELIST,
                                    IDPRECALT)
               SELECT ITEMCOLE.CDFILIAL, ITEMCOLE.NRCOLEPRECO, ITEMCOLE.CDPRODUTO, CDMARCA, ITEMCOLE.CDFORNECED,
                      @V_REGIAO_CDREGIAO, DTINIVALITM, DTFINVALITM,
                      VRPRECUNIITM, VRPERDESITM, 'S',
                      CDTIPCOB, CDSEGMARCCOL, IDTIPFREITM, NRPZOENTCOL,
                      IDITMLISPREC, CDFORMPGTO, IDTPFOPGTCOL, NRPARCPGTCOL,
                      NRDIAPGFXCOL, IDUTDIAPGCOL, QTACMPITMCOL,
                      DSPZOPGTCONC, @P_IDATUREG, @P_IDATUFORN, @V_NRSEQPRELIST,
                      @V_IDPRECALT
               FROM ITEMCOLE,
               		(SELECT
                        PARAMPRODSUP.CDREGIAO,
                        PARAMPRODSUP.CDPRODUTO
                     FROM
                        PARAMPRODSUP,
                        FILIAL
                     WHERE
                        FILIAL.CDFILIAL = @P_CDFILIPROC AND
                        FILIAL.IDFUNCAOFILI = 'C' AND
                        FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL AND
                        PARAMPRODSUP.IDFILINEGCOR = 'S'

                     UNION ALL

                     SELECT
                        PARAMPRODSUP.CDREGIAO,
                        PARAMPRODSUP.CDPRODUTO
                     FROM
                        PARAMPRODSUP,
                        FILIAL
                     WHERE
                        FILIAL.CDFILIAL = @P_CDFILIPROC  AND
                        FILIAL.IDFUNCAOFILI = 'R' AND
                        FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL AND
                        PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
               WHERE
                  ITEMCOLE.CDFILIAL    = @P_CDFILIAL    AND
                  ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO AND
                  ITEMCOLE.CDFORNECED  = @P_CDFORNECED  AND
                  ITEMCOLE.CDPRODUTO   = @P_CDPRODUTO   AND
                  CDMARCA              = @P_CDMARCA     AND
                  ITEMCOLE.CDREGIAO    = @P_CDREGIAO    AND

                  PARAMPRODSUP.CDPRODUTO = ITEMCOLE.CDPRODUTO AND
                  PARAMPRODSUP.CDREGIAO = @V_REGIAO_CDREGIAO

               UNION ALL

               SELECT ITEMCOLE.CDFILIAL, NRCOLEPRECO, CDPRODUTO, CDMARCA, CDFORNECED,
                      @V_REGIAO_CDREGIAO, DTINIVALITM, DTFINVALITM,
                      VRPRECUNIITM, VRPERDESITM, 'S',
                      CDTIPCOB, CDSEGMARCCOL, IDTIPFREITM, NRPZOENTCOL,
                      IDITMLISPREC, CDFORMPGTO, IDTPFOPGTCOL, NRPARCPGTCOL,
                      NRDIAPGFXCOL, IDUTDIAPGCOL, QTACMPITMCOL,
                      DSPZOPGTCONC, @P_IDATUREG, @P_IDATUFORN, @V_NRSEQPRELIST,
                      @V_IDPRECALT
               FROM ITEMCOLE,
                    FILIAL
               WHERE
                  ITEMCOLE.CDFILIAL    = @P_CDFILIAL    AND
                  NRCOLEPRECO = @P_NRCOLEPRECO AND
                  CDFORNECED  = @P_CDFORNECED  AND
                  CDPRODUTO   = @P_CDPRODUTO   AND
                  CDMARCA     = @P_CDMARCA     AND
                  ITEMCOLE.CDREGIAO    = @P_CDREGIAO    AND

                  FILIAL.CDFILIAL = @P_CDFILIPROC AND
                  ISNULL(FILIAL.IDFUNCAOFILI, '0') = '0';

               INSERT INTO PZOPGTITMCOL
               (CDFILIAL, NRCOLEPRECO,  CDFORNECED,   CDPRODUTO,
                CDMARCA,  NRDIASPGTCOL, VRPERCPGTCOL, CDREGIAO)
               SELECT
                PZOPGTITMCOL.CDFILIAL, PZOPGTITMCOL.NRCOLEPRECO, PZOPGTITMCOL.CDFORNECED,
                PZOPGTITMCOL.CDPRODUTO,PZOPGTITMCOL.CDMARCA, PZOPGTITMCOL.NRDIASPGTCOL,
                PZOPGTITMCOL.VRPERCPGTCOL, @V_REGIAO_CDREGIAO
               FROM
                PZOPGTITMCOL,
                ITEMCOLE
               WHERE
                PZOPGTITMCOL.CDFILIAL    = @P_CDFILIAL    AND
                PZOPGTITMCOL.NRCOLEPRECO = @P_NRCOLEPRECO AND
                PZOPGTITMCOL.CDREGIAO    = @P_CDREGIAO    AND
                (PZOPGTITMCOL.CDFORNECED = @P_CDFORNECED OR @P_TFORN = 'T') AND

                ITEMCOLE.CDREGIAO        = @V_REGIAO_CDREGIAO    AND
                ITEMCOLE.CDPRODUTO       = @P_CDPRODUTO          AND
                ITEMCOLE.CDMARCA         = @P_CDMARCA            AND
                PZOPGTITMCOL.CDFILIAL    = ITEMCOLE.CDFILIAL    AND
                PZOPGTITMCOL.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO AND
                PZOPGTITMCOL.CDFORNECED  = ITEMCOLE.CDFORNECED  AND
                PZOPGTITMCOL.CDPRODUTO   = ITEMCOLE.CDPRODUTO   AND
                PZOPGTITMCOL.CDMARCA     = ITEMCOLE.CDMARCA     AND
                NOT EXISTS (SELECT 1 FROM PZOPGTITMCOL P
                                    WHERE PZOPGTITMCOL.CDFILIAL         = P.CDFILIAL    AND
                                          PZOPGTITMCOL.NRCOLEPRECO      = P.NRCOLEPRECO AND
                                          PZOPGTITMCOL.CDFORNECED       = P.CDFORNECED  AND
                                          PZOPGTITMCOL.CDPRODUTO        = P.CDPRODUTO   AND
                                          PZOPGTITMCOL.CDMARCA          = P.CDMARCA     AND
                                          PZOPGTITMCOL.CDREGIAO         = P.CDREGIAO    AND
                                          PZOPGTITMCOL.NRDIASPGTCOL     = P.NRDIASPGTCOL);
            END;
         END;
      END;

      SET @V_DTCOLEPREC = NULL;
      SELECT  @V_DTCOLEPREC = MAX(DTCOLEPREC)
      FROM COLETAPR
      WHERE
         CDFILIAL    = @P_CDFILIAL AND
         NRCOLEPRECO = @P_NRCOLEPRECO;

      DECLARE C_PRECOS CURSOR FOR
         SELECT
           ITEMCOLE.CDFORNECED,
           ITEMCOLE.CDPRODUTO,
           PRODUTO.CDARVPROD,
           ITEMCOLE.CDMARCA,
           ITEMCOLE.VRPRECUNIITM,
           ITEMCOLE.CDFORMPGTO,
           ITEMCOLE.IDTPFOPGTCOL,
           ITEMCOLE.NRPARCPGTCOL,
           ITEMCOLE.NRDIAPGFXCOL,
           ITEMCOLE.IDUTDIAPGCOL
         FROM
           ITEMCOLE, PRODUTO
         WHERE
           ITEMCOLE.CDFILIAL    = @P_CDFILIAL                     AND
           ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO                  AND
           ITEMCOLE.CDREGIAO    = @P_CDREGIAO                     AND
           (CDFORNECED = @P_CDFORNECED OR @P_TFORN = 'T') AND
           ITEMCOLE.CDPRODUTO   = PRODUTO.CDPRODUTO           AND
           ITEMCOLE.CDPRODUTO   = ISNULL(@P_CDPRODUTO, ITEMCOLE.CDPRODUTO) AND
           ITEMCOLE.CDMARCA     = ISNULL(@P_CDMARCA, ITEMCOLE.CDMARCA);
         OPEN C_PRECOS;
         FETCH NEXT FROM C_PRECOS INTO @V_PRECOS_CDFORNECED,
                                       @V_PRECOS_CDPRODUTO,
                                       @V_PRECOS_CDARVPROD,
                                       @V_PRECOS_CDMARCA,
                                       @V_PRECOS_VRPRECUNIITM,
                                       @V_PRECOS_CDFORMPGTO,
                                       @V_PRECOS_IDTPFOPGTCOL,
                                       @V_PRECOS_NRPARCPGTCOL,
                                       @V_PRECOS_NRDIAPGFXCOL,
                                       @V_PRECOS_IDUTDIAPGCOL;
         WHILE (@@FETCH_STATUS = 0)
         BEGIN
/* CUSOR QUE RETORNARA TODOS ITENS QUE SERAO DUPLICADOS */

            UPDATE ITEMCOLE
            SET VRPRECUNIITM = @V_PRECOS_VRPRECUNIITM,
                CDFORMPGTO   = @V_PRECOS_CDFORMPGTO,
                IDTPFOPGTCOL = @V_PRECOS_IDTPFOPGTCOL,
                NRPARCPGTCOL = @V_PRECOS_NRPARCPGTCOL,
                NRDIAPGFXCOL = @V_PRECOS_NRDIAPGFXCOL,
                IDUTDIAPGCOL = @V_PRECOS_IDUTDIAPGCOL,
                IDITMCOTPREC = 'S',
                IDATUREGIALT = @P_IDATUREG,
                IDATUFORNALT = @P_IDATUFORN
            WHERE
              CDFILIAL    = @P_CDFILIAL     AND
              NRCOLEPRECO = @P_NRCOLEPRECO  AND
              CDREGIAO    = @V_REGIAO_CDREGIAO AND
              CDFORNECED  = @V_PRECOS_CDFORNECED AND
              CDPRODUTO   = @V_PRECOS_CDPRODUTO  AND
              CDMARCA     = @V_PRECOS_CDMARCA;

            IF @V_PRECOS_IDTPFOPGTCOL = 'V' BEGIN
               DELETE FROM PZOPGTITMCOL
               WHERE
                  CDFILIAL    = @P_CDFILIAL AND
                  NRCOLEPRECO = @P_NRCOLEPRECO AND
                  CDREGIAO    = @V_REGIAO_CDREGIAO AND
                  CDFORNECED  = @V_PRECOS_CDFORNECED AND
                  CDPRODUTO   = @V_PRECOS_CDPRODUTO AND
                  CDMARCA     = @V_PRECOS_CDMARCA;

               INSERT INTO PZOPGTITMCOL
                  (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
                   CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)
               SELECT
                  CDFILIAL,
                  NRCOLEPRECO,
                  CDFORNECED,
                  CDPRODUTO,
                  CDMARCA,
                  @V_REGIAO_CDREGIAO,
                  NRDIASPGTCOL,
                  VRPERCPGTCOL
               FROM
                  PZOPGTITMCOL
               WHERE
                  CDFILIAL    = @P_CDFILIAL AND
                  NRCOLEPRECO = @P_NRCOLEPRECO AND
                  CDREGIAO    = @P_CDREGIAO AND
                  CDFORNECED  = @V_PRECOS_CDFORNECED AND
                  CDPRODUTO   = @V_PRECOS_CDPRODUTO AND
                  CDMARCA     = @V_PRECOS_CDMARCA AND
                  NOT EXISTS (SELECT 1 FROM PZOPGTITMCOL P
                                      WHERE PZOPGTITMCOL.CDFILIAL         = P.CDFILIAL    AND
                                            PZOPGTITMCOL.NRCOLEPRECO      = P.NRCOLEPRECO AND
                                            PZOPGTITMCOL.CDFORNECED       = P.CDFORNECED  AND
                                            PZOPGTITMCOL.CDPRODUTO        = P.CDPRODUTO   AND
                                            PZOPGTITMCOL.CDMARCA          = P.CDMARCA     AND
                                            PZOPGTITMCOL.CDREGIAO         = P.CDREGIAO    AND
                                            PZOPGTITMCOL.NRDIASPGTCOL     = P.NRDIASPGTCOL);
            END;
/*###############################  IMPOSTO ######################################*/

              SET @V_CDEMPRESA = NULL;
              SELECT
                 @V_CDEMPRESA = MAX(EMITENTEAF.CDEMPRESA)
              FROM
                 EMITENTEAF, PRODUTO
              WHERE
                 EMITENTEAF.CDPRODUTO = PRODUTO.CDPRODUTO AND
                 EMITENTEAF.CDFILIAL  = @P_CDFILIAL AND
                 @V_PRECOS_CDARVPROD LIKE PRODUTO.CDARVPROD + '%';

              IF @V_CDEMPRESA IS NULL
              BEGIN
                 SET @V_CDEMPRESA = NULL;
                 SELECT
                    @V_CDEMPRESA = MAX(PARCMPSUP.CDEMPRESA)
                 FROM
                    PARCMPSUP
                 WHERE
                    PARCMPSUP.CDFILIAL = @P_CDFILIAL;
              END;

              SET @V_CDEMPRESA  = NULL;
              SET @V_CDINSCMUNI = NULL;
              SET @V_CDINSCESTA = NULL;
              SELECT
                 @V_CDEMPRESA  = MAX(EMPRESA.CDEMPRESA),
                 @V_CDINSCMUNI = MIN(INSCRMUNICIP.CDINSCMUNI),
                 @V_CDINSCESTA = MIN(INSCRESTAD.CDINSCESTA)
              FROM
                 EMPRESA,
                 INSCRMUNICIP,
                 INSCRESTAD
              WHERE
                 EMPRESA.CDEMPRESA = @V_CDEMPRESA           AND
                 EMPRESA.CDEMPRESA = INSCRMUNICIP.CDEMPRESA AND
                 EMPRESA.CDEMPRESA = INSCRESTAD.CDEMPRESA;

              EXEC IMPOSTO_ITEMCOL @V_CDEMPRESA,      @V_CDINSCESTA,        @V_PRECOS_CDFORNECED, @P_CDFILIAL,
                                   @P_NRCOLEPRECO,    @V_PRECOS_CDFORNECED, @V_REGIAO_CDREGIAO,   @V_PRECOS_CDPRODUTO,
                                   @V_PRECOS_CDMARCA, @V_DTCOLEPREC;

         FETCH NEXT FROM C_PRECOS INTO @V_PRECOS_CDFORNECED,
                                       @V_PRECOS_CDPRODUTO,
                                       @V_PRECOS_CDARVPROD,
                                       @V_PRECOS_CDMARCA,
                                       @V_PRECOS_VRPRECUNIITM,
                                       @V_PRECOS_CDFORMPGTO,
                                       @V_PRECOS_IDTPFOPGTCOL,
                                       @V_PRECOS_NRPARCPGTCOL,
                                       @V_PRECOS_NRDIAPGFXCOL,
                                       @V_PRECOS_IDUTDIAPGCOL;
      END;
      CLOSE C_PRECOS;
      DEALLOCATE C_PRECOS;
      FETCH NEXT FROM C_REGIAO INTO @V_REGIAO_CDREGIAO;
   END;
   CLOSE C_REGIAO;
   DEALLOCATE C_REGIAO;
END;

GO

-- VERSAO --
EXEC ATUVEROBJ 'PRECOS_TO_REGIAO','4.11.110';
GO

