import { Http, Loader, Metadata, Singleton } from '@zeedhi/core';
import { OperadorController } from '@/controllers/Operador/OperadorController';
import { OperadorService } from '@/services/OperadorService';
import { IGridEvent, LoadingService, Modal, ModalService } from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import AclMessages from '@/Util/AclMessages';
import { PmLibAlertService, PmLibDialogService, PmLibHttp } from '@zeedhi/pm-lib';

@Singleton
export class TabOrganizacoesRelacionadasController {
	public operadorControler: OperadorController;

	public operadorService: OperadorService;

	constructor() {
		this.operadorControler = Loader.getInstance('OperadorController');
		this.operadorService = new OperadorService();
	}

	/** Grid Component */

	public getRelateOrganizacoesByOperadorGrid(): TekGrid {
		return Metadata.getInstance<TekGrid>('relateOrganizacoesByOperadorGrid');
	}

	public getOrganizacoesRelacionadasGrid(): TekGrid {
		return Metadata.getInstance<TekGrid>('organizacoesRelacionadasGrid');
	}

	public async onMountedOrganizacoesRelacionadasGrid() {
		this.relateOrganizacoesByOperadorModal = await ModalService.createFromJson(this.relateOrganizacoesByOperadorModalPath, true);
	}

	public async addClickOrganizacoesRelacionadasGrid() {
		await this.relateOrganizacoesByOperadorModal.show();
		const grid = this.getRelateOrganizacoesByOperadorGrid();
		grid.datasource.addFilter('CDOPERADOR', this.operadorControler.currentOperador.CDOPERADOR);
	}

	public async beforeSaveOrganizacoesRelacionadasGrid({ event }: IGridEvent) {
		event?.preventDefault();
	}

	public async beforeDeleteOrganizacoesRelacionadasGrid({ event }: IGridEvent) {
		event?.preventDefault();
		const grid = this.getOrganizacoesRelacionadasGrid();
		const nrorgrel = grid.selectedRows[0].NRORGREL;
		if (this.operadorControler.operador.NRORGTRABLOGGED !== nrorgrel) {
			PmLibDialogService.showError(AclMessages.ERROR_DELETE_RELATE_ORGANIZACAO);
			grid.selectedRows = [];
		} else {
			const confirm = await PmLibDialogService.confirmDialog(AclMessages.DELETE_DEFAULT);
			if (confirm) {
				this.deleteOrganizacaooper();
			}
		}
	}

	private async deleteOrganizacaooper() {
		const grid = this.getOrganizacoesRelacionadasGrid();
		await PmLibHttp.$delete('/organizacao/organizacaooper', { data: grid.selectedRows });
		PmLibAlertService.showSuccess(AclMessages.SUCCESS_DELETE_DEAFULT);
		await grid.reload();
	}

	public onDestroyedGridOrganizacoesRelacionadasGrid() {
		this.relateOrganizacoesByOperadorModal.destroy();
	}

	/** Form Modal Component */
	public relateOrganizacoesByOperadorModal!: Modal;

	public relateOrganizacoesByOperadorModalPath: string = 'components/operador/detail/tabs/organizacoesRelacionadas/modais/relateOrganizacoesByOperador';

	public async closeRelateOrganizacoesByOperadorModal() {
		this.relateOrganizacoesByOperadorModal.hide();
		this.getOrganizacoesRelacionadasGrid().reload();
	}

	public get validateSaveButton(): boolean {
		const grid = this.getRelateOrganizacoesByOperadorGrid();
		return !grid.selectedRows.length;
	}

	public async createOrganizacaooper() {
		const grid = this.getRelateOrganizacoesByOperadorGrid();
		const { selectedRows } = grid;
		const dataset = selectedRows.map((row) => ({
			NRORG: row.NRORG,
			CDOPERADOR: this.operadorControler.currentOperador.CDOPERADOR,
		}));

		try {
			LoadingService.show();
			await Http.post('/organizacao/organizacaooper', dataset);
			LoadingService.hide();
			PmLibAlertService.showSuccess(AclMessages.SUCCESS_RELATE_ORGANIZACOES);
			grid.selectedRows = [];
			await grid.reload();
		} catch (e) {
			LoadingService.hide();
			PmLibDialogService.showErrorBackend(e);
		}
	}
}
