import { Http, Loader, Metadata, Singleton } from '@zeedhi/core';
import { LoadingService, Tabs } from '@zeedhi/common';
import { PmLibDialogService, PmLibUtil, PmLibHttp } from '@zeedhi/pm-lib';
import { TekLibLocalStorage } from '@zeedhi/tek-lib';
import { TabLabelsTreeController } from '@/controllers/PerfilDeAcesso/detail/tabs/TabLabelsTreeController';
import { TabPerfilDeAcessoOperadorController } from '@/controllers/PerfilDeAcesso/detail/tabs/TabPerfilDeAcessoOperadorController';
import { TekGrid } from '@zeedhi/teknisa-components-common';

@Singleton
export class PerfilDeAcessoController {
	public containerLabel!: string;

	public actionEnableAccessProfileLabel!: string;

	public accesControl!: boolean;

	public currentCdoperador: string = '';

	public currentNrorg: string = '';

	public isVisibleGridAndDetail = true;

	public currentPerfilDeAcesso: any = {};

	public getCurrentNrperfilacesso() {
		return this.currentPerfilDeAcesso.NRPERFILACESSO;
	}

	/** ******************************************
	 ******* Perfil de Acesso Card Section *******
	 ******************************************** */

	public async onCreatedPerfilDeAcessoCard() {
		try {
			PmLibUtil.validateNovocodigo();
			// this.findAccessControlUtilization();
			const { data: { data } } = await PmLibHttp.$get('/operador-label-version');
			if (data.length) {
				const version = parseInt(data[0].NRULTVERSAO, 10);
				TekLibLocalStorage.setItem('oldMajorVersion', version);
			} else {
				TekLibLocalStorage.setItem('oldMajorVersion', 1);
			}
		} catch (e) {
			LoadingService.hide();
			PmLibDialogService.showErrorBackend(e);
		}
	}

	private async findAccessControlUtilization() {
		const response = await Http.get('/findAccessControlUtilization');
		let idutctrlacesweb: string;

		if (response.data.IDUTCTRLACESWEB) {
			idutctrlacesweb = response.data.IDUTCTRLACESWEB;
		} else {
			idutctrlacesweb = 'N';
		}

		localStorage.setItem('idutctrlacesweb', idutctrlacesweb);
		this.currentCdoperador = response.data.CDOPERADOR;
		this.currentNrorg = response.data.NRORG;
		this.changeLabelEnableAccessProfile(idutctrlacesweb);
	}

	private changeLabelEnableAccessProfile(idutctrlacesweb: string) {
		// const perfilDeAcessoGridController: PerfilDeAcessoGridController = Loader.getInstance('PerfilDeAcessoGridController');
		const grid = Metadata.getInstance<TekGrid>('perfilDeAcessoGrid');
		grid.title = 'Teste';
		if (idutctrlacesweb === 'N') {
			this.accesControl = false;
			// perfilDeAcessoGridController.gridTitle = 'Perfil de Acesso (Controle de Acesso Desativado)';
			// perfilDeAcessoGridController.actionEnablePerfilAcessoLabel = 'Ativar controle de acesso';
		} else {
			this.accesControl = true;
			// perfilDeAcessoGridController.gridTitle = 'Perfil de Acesso';
			// perfilDeAcessoGridController.actionEnablePerfilAcessoLabel = 'Desativar controle de acesso';
		}
	}

	public destroyPerfilDeAcessoCard() {}

	/** *******************************************
	 ******* Perfil de Acesso Detail Section *******
	 ******************************************** */

	public async changePerfilDeAcessoDetailTabs() {
		const tabs = Metadata.getInstance<Tabs>('perfilDeAcessoDetailTabs');
		if (tabs.activeTab === 0) {
			const tabPerfilDeAcessoOperadorController: TabPerfilDeAcessoOperadorController = Loader.getInstance('TabPerfilDeAcessoOperadorController');
			await tabPerfilDeAcessoOperadorController.onActiveTab();
		}

		if (tabs.activeTab === 1) {
			const tabLabelsTreeController: TabLabelsTreeController = Loader.getInstance('TabLabelsTreeController');
			await tabLabelsTreeController.onActiveTab();
		}
	}
}
